@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,27 +26,23 @@
 #include <fcntl.h>
 #include <errno.h>
 
-#ifdef HAVE_IO_H
-#  include <io.h>
-#  define pipe(phandles) _pipe(phandles, 4096, _O_BINARY)
-#else
-#  ifdef HAVE_UNISTD_H
-#    include <unistd.h>
-#  endif
-#endif
-
 #ifdef HAVE_SYS_WAIT_H
 #  include <sys/wait.h>
 #endif
 
-#include <glib.h>
-
 #include "cut-pipeline.h"
 #include "cut-test-result.h"
 #include "cut-runner.h"
 #include "cut-experimental.h"
 #include "cut-utils.h"
 
+#ifdef G_OS_WIN32
+#  include <io.h>
+#  define pipe(phandles) _pipe(phandles, 4096, _O_BINARY)
+#else
+#  include <unistd.h>
+#endif
+
 #define CUT_PIPELINE_GET_PRIVATE(obj) \
     (G_TYPE_INSTANCE_GET_PRIVATE((obj), CUT_TYPE_PIPELINE, CutPipelinePrivate))
 
@@ -461,6 +457,7 @@ run_async (CutPipeline *pipeline)
     result = g_spawn_async_with_pipes(NULL,
                                       command_line_args,
                                       NULL,
+                                      G_SPAWN_SEARCH_PATH |
                                       G_SPAWN_LEAVE_DESCRIPTORS_OPEN |
                                       G_SPAWN_DO_NOT_REAP_CHILD,
 #ifndef G_OS_WIN32
