@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007-2009  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2007-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,12 +35,12 @@
 #include <glib/gi18n-lib.h>
 
 #ifdef G_OS_WIN32
+#  ifdef __MINGW32__
+#    define _WIN32_WINDOWS 0x0401 /* to get IsDebuggerPresent */
+#  endif
+#  include <winsock2.h>
 #  include <process.h>		/* For getpid() */
 #  include <io.h>
-#  define STRICT		/* Strict typing, please */
-#  define _WIN32_WINDOWS 0x0401 /* to get IsDebuggerPresent */
-#  include <windows.h>
-#  undef STRICT
 #endif
 
 #include "cut-run-context.h"
@@ -72,6 +72,7 @@ struct _CutTestContextPrivate
     CutTestIterator *test_iterator;
     CutTest *test;
     gboolean failed;
+    gboolean omitted;
     gboolean is_multi_thread;
     jmp_buf *jump_buffer;
     GList *taken_objects;
@@ -92,7 +93,7 @@ struct _CutTestContextPrivate
     gchar *expected;
     gchar *actual;
     CutTestResult *current_result;
-    gboolean have_user_message_jump;
+    guint user_message_jump_nest;
 };
 
 enum
@@ -242,6 +243,7 @@ cut_test_context_init (CutTestContext *context)
     priv->test = NULL;
 
     priv->failed = FALSE;
+    priv->omitted = FALSE;
     priv->is_multi_thread = FALSE;
 
     priv->taken_objects = NULL;
@@ -267,7 +269,7 @@ cut_test_context_init (CutTestContext *context)
 
     priv->current_result = NULL;
 
-    priv->have_user_message_jump = FALSE;
+    priv->user_message_jump_nest = 0;
 }
 
 static void
@@ -838,8 +840,10 @@ cut_test_context_set_current_result (CutTestContext *context,
 
     priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
     clear_current_result(priv);
-    if (cut_test_result_status_is_critical(status))
+    if (cut_test_result_status_is_critical(status)) {
         priv->failed = TRUE;
+    }
+    priv->omitted = (status == CUT_TEST_RESULT_OMISSION);
 
     if (priv->current_data)
         test_data = priv->current_data->data;
@@ -943,16 +947,21 @@ cut_test_context_register_result (CutTestContext *context,
 }
 
 void
-cut_test_context_set_have_user_message_jump (CutTestContext *context,
-                                             gboolean have)
+cut_test_context_start_user_message_jump (CutTestContext *context)
 {
-    CUT_TEST_CONTEXT_GET_PRIVATE(context)->have_user_message_jump = have;
+    CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_message_jump_nest++;
+}
+
+void
+cut_test_context_finish_user_message_jump (CutTestContext *context)
+{
+    CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_message_jump_nest--;
 }
 
 gboolean
-cut_test_context_get_have_user_message_jump (CutTestContext *context)
+cut_test_context_in_user_message_jump (CutTestContext *context)
 {
-    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->have_user_message_jump;
+    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_message_jump_nest > 0;
 }
 
 void
@@ -967,6 +976,13 @@ cut_test_context_is_failed (CutTestContext *context)
     return CUT_TEST_CONTEXT_GET_PRIVATE(context)->failed;
 }
 
+gboolean
+cut_test_context_need_test_run (CutTestContext *context)
+{
+    return !cut_test_context_is_failed(context) &&
+        !CUT_TEST_CONTEXT_GET_PRIVATE(context)->omitted;
+}
+
 const void *
 cut_test_context_take (CutTestContext *context,
                        void           *object,
