@@ -209,11 +209,25 @@ extern "C" {
 #define cut_take_convert(string, to_code_set, from_code_set)            \
     cut_take_convert_helper(                                            \
         string, to_code_set, from_code_set,                             \
-        (cut_push_backtrace(cut_take_code_set(string,                   \
-                                              to_code_set,              \
-                                              from_code_set)),          \
+        (cut_push_backtrace(cut_take_convert(string,                    \
+                                             to_code_set,               \
+                                             from_code_set)),           \
          cut_pop_backtrace))
 
+/**
+ * cut_take_inspect_string:
+ * @string: the inspect target string. It should be %NULL or
+ *          %NULL-terminated.
+ *
+ * Inspects @string.
+ *
+ * Returns: a inspected string owned by Cutter. Don't free it.
+ *
+ * Since: 1.1.4
+ */
+#define cut_take_inspect_string(string)                                 \
+    cut_take_string(cut_utils_inspect_string(string))
+
 /**
  * cut_set_fixture_data_dir:
  * @path: a first element of the path to the fixture data directory.
@@ -297,6 +311,19 @@ extern "C" {
 #define cut_build_path(...)                                            \
     cut_take_string(cut_utils_build_path(__VA_ARGS__))
 
+/**
+ * cut_build_path_array:
+ * @paths: %NULL-terminated array of strings containing the path elements.
+ *
+ * Builds path from @paths.
+ *
+ * Returns: built path owned by Cutter. Don't free it.
+ *
+ * Since: 1.1.5
+ */
+#define cut_build_path_array(paths)                     \
+    cut_take_string(cut_utils_build_path_array(paths))
+
 /**
  * cut_make_directory:
  * @path: a first element of the path to be made.
