@@ -109,6 +109,9 @@ module RD
       case lines.first.strip
       when "# RT"
         apply_to_RT(lines.join)
+      when "# note"
+        contents = lines[1..-1].collect {|line| apply_to_String(line)}
+        tag("note", {}, contents.join("").chomp)
       else
         contents = lines.collect {|line| apply_to_String(line)}
         tag("programlisting", {}, contents.join("").chomp)
@@ -229,10 +232,15 @@ module RD
 
     def apply_to_DescListItem(element, term, contents)
       term_attributes = {}
-      id = term_index_id(term)
-      unless @term_indexes[id]
-        @term_indexes[id] = term
-        term_attributes["id"] = "#{ref_entry_id}.#{id}"
+      term = term.join("")
+      if /\A\s*\[\]\s*/ =~ term
+        term = $POSTMATCH
+      else
+        id = term_index_id(term)
+        unless @term_indexes[id]
+          @term_indexes[id] = term
+          term_attributes["id"] = "#{ref_entry_id}.#{id}"
+        end
       end
       tag("varlistentry", {},
           tag("term", term_attributes, term),
