@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,11 +38,13 @@
 #endif
 
 #ifdef G_OS_WIN32
-#define LINE_FEED_CODE "\r\n"
+#  define LINE_FEED_CODE "\r\n"
 #else
-#define LINE_FEED_CODE "\n"
+#  define LINE_FEED_CODE "\n"
 #endif
 
+#include "../lib/cuttest-utils.h"
+
 void test_help (void);
 void test_help_all (void);
 void test_version (void);
@@ -51,6 +53,7 @@ void test_invalid_color_option (void);
 void test_invalid_order_option (void);
 void test_invalid_verbose_option (void);
 void test_no_option (void);
+void test_get_test_directory (void);
 
 static gchar *stdout_string = NULL;
 static gchar *stderr_string = NULL;
@@ -80,7 +83,8 @@ cut_setup (void)
     exit_status = 0;
     lang = g_strdup(g_getenv("LANG"));
 
-    format =        "Usage:" LINE_FEED_CODE
+    format =
+        "Usage:" LINE_FEED_CODE
         "  %s [OPTION...] TEST_DIRECTORY" LINE_FEED_CODE
         "  %s --mode=analyze [OPTION...] LOG_DIRECTORY" LINE_FEED_CODE
         "" LINE_FEED_CODE
@@ -332,6 +336,19 @@ test_invalid_verbose_option (void)
                             stdout_string);
 }
 
+void
+test_get_test_directory (void)
+{
+    const gchar *test_dir;
+    test_dir = cut_build_path(cuttest_get_base_dir(),
+                              "fixtures",
+                              "test-directory",
+                              NULL);
+    cut_assert(run_cutter(test_dir));
+    cut_assert_exit_success();
+}
+
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
