@@ -4,6 +4,10 @@ BASE_DIR="`dirname $0`"
 export BASE_DIR
 top_dir="$BASE_DIR/.."
 
+if test x"$RUNNING_TEST" = x"yes"; then
+    exit 0
+fi
+
 if test x"$NO_MAKE" != x"yes"; then
     if test -z "$MAKE"; then
 	if which gmake 2>&1 > /dev/null; then
@@ -12,7 +16,9 @@ if test x"$NO_MAKE" != x"yes"; then
 	    MAKE=make
 	fi
     fi
-    $MAKE -C $top_dir/ > /dev/null || exit 1
+    RUNNING_TEST=yes
+    export RUNNING_TEST
+    $MAKE -C $top_dir/ check INTLTOOL_UPDATE=: > /dev/null || exit 1
 fi
 
 if test -z "$CUTTER"; then
@@ -60,15 +66,21 @@ case `uname` in
     CYGWIN*)
 	PATH="$top_dir/cutter/.libs:$PATH"
 	PATH="$top_dir/gcutter/.libs:$PATH"
+	PATH="$top_dir/cppcutter/.libs:$PATH"
 	PATH="$top_dir/gdkcutter-pixbuf/.libs:$PATH"
+	PATH="$top_dir/soupcutter/.libs:$PATH"
 	PATH="$top_dir/test/lib/.libs:$PATH"
 	;;
     Darwin)
+	DYLD_LIBRARY_PATH="$top_dir/cppcutter/.libs:$DYLD_LIBRARY_PATH"
 	DYLD_LIBRARY_PATH="$top_dir/gdkcutter-pixbuf/.libs:$DYLD_LIBRARY_PATH"
+	DYLD_LIBRARY_PATH="$top_dir/soupcutter/.libs:$DYLD_LIBRARY_PATH"
 	export DYLD_LIBRARY_PATH
 	;;
     *BSD)
+	LD_LIBRARY_PATH="$top_dir/cppcutter/.libs:$LD_LIBRARY_PATH"
 	LD_LIBRARY_PATH="$top_dir/gdkcutter-pixbuf/.libs:$LD_LIBRARY_PATH"
+	LD_LIBRARY_PATH="$top_dir/soupcutter/.libs:$LD_LIBRARY_PATH"
 	export LD_LIBRARY_PATH
         ;;
     *)
@@ -76,4 +88,6 @@ case `uname` in
 	;;
 esac
 
+LC_ALL=C
+export LC_ALL
 $CUTTER_WRAPPER $CUTTER $CUTTER_ARGS "$@" $BASE_DIR
